@@ -9,7 +9,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '1.999';
 $VERSION = eval $VERSION; ## no critic
 
 use base 'Metabase::Report';
@@ -34,11 +34,19 @@ sub report_spec {
 sub content_metadata {
   my ($self) = @_;
   for my $fact ( $self->facts ) {
-    next unless $fact->type eq 'CPAN::Testers::Fact::LegacyReport';
+    next unless $fact->type eq 'CPAN-Testers-Fact-LegacyReport';
     return $fact->content_metadata;
   }
 }
   
+sub content_metadata_types {
+  my ($self) = @_;
+  for my $fact ( $self->facts ) {
+    next unless $fact->type eq 'CPAN::Testers::Fact::LegacyReport';
+    return $fact->content_metadata_types;
+  }
+}
+  
 1;
 
 __END__
